.. _core_internal_toplevel:

Core Internals
==============

Some key internal constructs are listed here.

.. currentmodule: sqlalchemy

.. autoclass:: sqlalchemy.engine.base.Compiled
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: sqlalchemy.sql.compiler.DDLCompiler
    :members:
    :show-inheritance:

.. autoclass:: sqlalchemy.engine.default.DefaultDialect
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: sqlalchemy.engine.base.Dialect
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: sqlalchemy.engine.default.DefaultExecutionContext
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: sqlalchemy.engine.base.ExecutionContext
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: sqlalchemy.sql.compiler.IdentifierPreparer
    :members:
    :show-inheritance:

.. autoclass:: sqlalchemy.sql.compiler.SQLCompiler
    :members:
    :show-inheritance:

